@@ -1,7 +1,12 @@
 from optparse import make_option
 
+import django
 from django.conf import settings
-from django.core.management.commands.test import Command as TestCommand
+
+if django.VERSION[0] == 1 and django.VERSION[1] >= 6:
+    from django.core.management.commands.test import Command as TestCommand
+else:
+    from discover_runner.management.commands.test import Command as TestCommand
 
 
 class Command(TestCommand):
